import fs from 'fs-extra';
import { XMLParser } from 'fast-xml-parser';
import { resolve } from 'path';
import process from 'child_process';
async function getGamesaveutilDir() {
    const gamesaveutilDir = 'C:/Program Files (x86)/Windows Kits/10/bin/10.0.19041.0/x64/gamesaveutil.exe';
    if (!fs.existsSync(gamesaveutilDir)) {
        throw new Error('Could not find Windows Kits 10.0.19041. Please install it from https://go.microsoft.com/fwlink/?linkid=2120843');
    }
    else {
        return gamesaveutilDir;
    }
}
export default async function exporUwpData(pfn, scid) {
    const gamesaveutilDir = await getGamesaveutilDir();
    const xmlFn = 'uwpData.xml';
    process.spawnSync(gamesaveutilDir, ['export', xmlFn, `/pfn:${pfn}`, `/scid:${scid}`], { stdio: 'inherit' });
    const rootDir = 'export';
    const xmlBody = fs.readFileSync(resolve(xmlFn), 'utf8').replace(/\s/g, '');
    const parser = new XMLParser();
    const jObj = parser.parse(xmlBody);
    const containers = jObj.XbConnectedStorageSpace.Data.Containers;
    const keys = Object.keys(containers);
    keys.forEach((containerKey) => {
        const containerFilePath = containerKey
            .replace(/Containername="/g, '')
            .replace(/"displayName=".*"/g, '');
        const container = containers[containerKey];
        const blobs = container.Blobs;
        const blobKeys = Object.keys(blobs);
        blobKeys.forEach((blobKey) => {
            const blobFilePath = blobKey.replace(/Blobname="/g, '').replace(/"/g, '');
            const blob = blobs[blobKey];
            const buff = Buffer.from(blob, 'base64');
            const base64data = buff.toString('utf8');
            const fullPath = resolve(rootDir, containerFilePath, blobFilePath);
            fs.ensureFileSync(fullPath);
            fs.writeFileSync(fullPath, base64data, { encoding: 'utf8' });
        });
    });
}
//# sourceMappingURL=uwp-export.js.map